import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The Disks API.
 * @class
 * @memberof v1
 */
export declare class DisksClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    disksStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of DisksClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    addResourcePolicies(request: protos.google.cloud.compute.v1.IAddResourcePoliciesDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IAddResourcePoliciesDiskRequest | undefined),
        {} | undefined
    ]>;
    addResourcePolicies(request: protos.google.cloud.compute.v1.IAddResourcePoliciesDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAddResourcePoliciesDiskRequest | null | undefined, {} | null | undefined>): void;
    addResourcePolicies(request: protos.google.cloud.compute.v1.IAddResourcePoliciesDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAddResourcePoliciesDiskRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListDisksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IDiskAggregatedList,
        protos.google.cloud.compute.v1.IAggregatedListDisksRequest | undefined,
        {} | undefined
    ]>;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListDisksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IDiskAggregatedList, protos.google.cloud.compute.v1.IAggregatedListDisksRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListDisksRequest, callback: Callback<protos.google.cloud.compute.v1.IDiskAggregatedList, protos.google.cloud.compute.v1.IAggregatedListDisksRequest | null | undefined, {} | null | undefined>): void;
    createSnapshot(request: protos.google.cloud.compute.v1.ICreateSnapshotDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.ICreateSnapshotDiskRequest | undefined,
        {} | undefined
    ]>;
    createSnapshot(request: protos.google.cloud.compute.v1.ICreateSnapshotDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ICreateSnapshotDiskRequest | null | undefined, {} | null | undefined>): void;
    createSnapshot(request: protos.google.cloud.compute.v1.ICreateSnapshotDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ICreateSnapshotDiskRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeleteDiskRequest | undefined,
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteDiskRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteDiskRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IDisk,
        protos.google.cloud.compute.v1.IGetDiskRequest | undefined,
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IDisk, protos.google.cloud.compute.v1.IGetDiskRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IDisk, protos.google.cloud.compute.v1.IGetDiskRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.IGetIamPolicyDiskRequest | undefined,
        {} | undefined
    ]>;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicyDiskRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicyDiskRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IInsertDiskRequest | undefined,
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertDiskRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertDiskRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListDisksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IDiskList,
        protos.google.cloud.compute.v1.IListDisksRequest | undefined,
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListDisksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IDiskList, protos.google.cloud.compute.v1.IListDisksRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListDisksRequest, callback: Callback<protos.google.cloud.compute.v1.IDiskList, protos.google.cloud.compute.v1.IListDisksRequest | null | undefined, {} | null | undefined>): void;
    removeResourcePolicies(request: protos.google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest | undefined),
        {} | undefined
    ]>;
    removeResourcePolicies(request: protos.google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest | null | undefined, {} | null | undefined>): void;
    removeResourcePolicies(request: protos.google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRemoveResourcePoliciesDiskRequest | null | undefined, {} | null | undefined>): void;
    resize(request: protos.google.cloud.compute.v1.IResizeDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IResizeDiskRequest | undefined,
        {} | undefined
    ]>;
    resize(request: protos.google.cloud.compute.v1.IResizeDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IResizeDiskRequest | null | undefined, {} | null | undefined>): void;
    resize(request: protos.google.cloud.compute.v1.IResizeDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IResizeDiskRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.ISetIamPolicyDiskRequest | undefined,
        {} | undefined
    ]>;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicyDiskRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicyDiskRequest | null | undefined, {} | null | undefined>): void;
    setLabels(request: protos.google.cloud.compute.v1.ISetLabelsDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.ISetLabelsDiskRequest | undefined,
        {} | undefined
    ]>;
    setLabels(request: protos.google.cloud.compute.v1.ISetLabelsDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetLabelsDiskRequest | null | undefined, {} | null | undefined>): void;
    setLabels(request: protos.google.cloud.compute.v1.ISetLabelsDiskRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetLabelsDiskRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsDiskRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ITestPermissionsResponse,
        protos.google.cloud.compute.v1.ITestIamPermissionsDiskRequest | undefined,
        {} | undefined
    ]>;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsDiskRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsDiskRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsDiskRequest, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsDiskRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
