import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The GlobalNetworkEndpointGroups API.
 * @class
 * @memberof v1
 */
export declare class GlobalNetworkEndpointGroupsClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    globalNetworkEndpointGroupsStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of GlobalNetworkEndpointGroupsClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    attachNetworkEndpoints(request: protos.google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest | undefined),
        {} | undefined
    ]>;
    attachNetworkEndpoints(request: protos.google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    attachNetworkEndpoints(request: protos.google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAttachNetworkEndpointsGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest | undefined),
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    detachNetworkEndpoints(request: protos.google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest | undefined),
        {} | undefined
    ]>;
    detachNetworkEndpoints(request: protos.google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    detachNetworkEndpoints(request: protos.google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDetachNetworkEndpointsGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INetworkEndpointGroup,
        (protos.google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest | undefined),
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INetworkEndpointGroup, protos.google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest, callback: Callback<protos.google.cloud.compute.v1.INetworkEndpointGroup, protos.google.cloud.compute.v1.IGetGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest | undefined),
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertGlobalNetworkEndpointGroupRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INetworkEndpointGroupList,
        (protos.google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest | undefined),
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INetworkEndpointGroupList, protos.google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest, callback: Callback<protos.google.cloud.compute.v1.INetworkEndpointGroupList, protos.google.cloud.compute.v1.IListGlobalNetworkEndpointGroupsRequest | null | undefined, {} | null | undefined>): void;
    listNetworkEndpoints(request: protos.google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints,
        (protos.google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest | undefined),
        {} | undefined
    ]>;
    listNetworkEndpoints(request: protos.google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints, protos.google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest | null | undefined, {} | null | undefined>): void;
    listNetworkEndpoints(request: protos.google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest, callback: Callback<protos.google.cloud.compute.v1.INetworkEndpointGroupsListNetworkEndpoints, protos.google.cloud.compute.v1.IListNetworkEndpointsGlobalNetworkEndpointGroupsRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
