import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The Images API.
 * @class
 * @memberof v1
 */
export declare class ImagesClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    imagesStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of ImagesClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeleteImageRequest | undefined,
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteImageRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteImageRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteImageRequest | null | undefined, {} | null | undefined>): void;
    deprecate(request: protos.google.cloud.compute.v1.IDeprecateImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeprecateImageRequest | undefined,
        {} | undefined
    ]>;
    deprecate(request: protos.google.cloud.compute.v1.IDeprecateImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeprecateImageRequest | null | undefined, {} | null | undefined>): void;
    deprecate(request: protos.google.cloud.compute.v1.IDeprecateImageRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeprecateImageRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IImage,
        protos.google.cloud.compute.v1.IGetImageRequest | undefined,
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IImage, protos.google.cloud.compute.v1.IGetImageRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetImageRequest, callback: Callback<protos.google.cloud.compute.v1.IImage, protos.google.cloud.compute.v1.IGetImageRequest | null | undefined, {} | null | undefined>): void;
    getFromFamily(request: protos.google.cloud.compute.v1.IGetFromFamilyImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IImage,
        protos.google.cloud.compute.v1.IGetFromFamilyImageRequest | undefined,
        {} | undefined
    ]>;
    getFromFamily(request: protos.google.cloud.compute.v1.IGetFromFamilyImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IImage, protos.google.cloud.compute.v1.IGetFromFamilyImageRequest | null | undefined, {} | null | undefined>): void;
    getFromFamily(request: protos.google.cloud.compute.v1.IGetFromFamilyImageRequest, callback: Callback<protos.google.cloud.compute.v1.IImage, protos.google.cloud.compute.v1.IGetFromFamilyImageRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.IGetIamPolicyImageRequest | undefined,
        {} | undefined
    ]>;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicyImageRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyImageRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicyImageRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IInsertImageRequest | undefined,
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertImageRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertImageRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertImageRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListImagesRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IImageList,
        protos.google.cloud.compute.v1.IListImagesRequest | undefined,
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListImagesRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IImageList, protos.google.cloud.compute.v1.IListImagesRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListImagesRequest, callback: Callback<protos.google.cloud.compute.v1.IImageList, protos.google.cloud.compute.v1.IListImagesRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IPatchImageRequest | undefined,
        {} | undefined
    ]>;
    patch(request: protos.google.cloud.compute.v1.IPatchImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchImageRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchImageRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchImageRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.ISetIamPolicyImageRequest | undefined,
        {} | undefined
    ]>;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicyImageRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyImageRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicyImageRequest | null | undefined, {} | null | undefined>): void;
    setLabels(request: protos.google.cloud.compute.v1.ISetLabelsImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.ISetLabelsImageRequest | undefined,
        {} | undefined
    ]>;
    setLabels(request: protos.google.cloud.compute.v1.ISetLabelsImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetLabelsImageRequest | null | undefined, {} | null | undefined>): void;
    setLabels(request: protos.google.cloud.compute.v1.ISetLabelsImageRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetLabelsImageRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsImageRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ITestPermissionsResponse,
        (protos.google.cloud.compute.v1.ITestIamPermissionsImageRequest | undefined),
        {} | undefined
    ]>;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsImageRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsImageRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsImageRequest, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsImageRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
