import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The InstanceGroupManagers API.
 * @class
 * @memberof v1
 */
export declare class InstanceGroupManagersClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    instanceGroupManagersStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of InstanceGroupManagersClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    abandonInstances(request: protos.google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    abandonInstances(request: protos.google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    abandonInstances(request: protos.google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAbandonInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManagerAggregatedList,
        (protos.google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagerAggregatedList, protos.google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagerAggregatedList, protos.google.cloud.compute.v1.IAggregatedListInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    applyUpdatesToInstances(request: protos.google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    applyUpdatesToInstances(request: protos.google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    applyUpdatesToInstances(request: protos.google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IApplyUpdatesToInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    createInstances(request: protos.google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    createInstances(request: protos.google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    createInstances(request: protos.google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ICreateInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deleteInstances(request: protos.google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    deleteInstances(request: protos.google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deleteInstances(request: protos.google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deletePerInstanceConfigs(request: protos.google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    deletePerInstanceConfigs(request: protos.google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deletePerInstanceConfigs(request: protos.google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeletePerInstanceConfigsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManager,
        (protos.google.cloud.compute.v1.IGetInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManager, protos.google.cloud.compute.v1.IGetInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManager, protos.google.cloud.compute.v1.IGetInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IInsertInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManagerList,
        (protos.google.cloud.compute.v1.IListInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagerList, protos.google.cloud.compute.v1.IListInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagerList, protos.google.cloud.compute.v1.IListInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listErrors(request: protos.google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse,
        (protos.google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    listErrors(request: protos.google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse, protos.google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listErrors(request: protos.google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagersListErrorsResponse, protos.google.cloud.compute.v1.IListErrorsInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listManagedInstances(request: protos.google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse,
        (protos.google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    listManagedInstances(request: protos.google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse, protos.google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listManagedInstances(request: protos.google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagersListManagedInstancesResponse, protos.google.cloud.compute.v1.IListManagedInstancesInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listPerInstanceConfigs(request: protos.google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp,
        (protos.google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    listPerInstanceConfigs(request: protos.google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp, protos.google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listPerInstanceConfigs(request: protos.google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManagersListPerInstanceConfigsResp, protos.google.cloud.compute.v1.IListPerInstanceConfigsInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IPatchInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    patch(request: protos.google.cloud.compute.v1.IPatchInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    patchPerInstanceConfigs(request: protos.google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    patchPerInstanceConfigs(request: protos.google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    patchPerInstanceConfigs(request: protos.google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchPerInstanceConfigsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    recreateInstances(request: protos.google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    recreateInstances(request: protos.google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    recreateInstances(request: protos.google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRecreateInstancesInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    resize(request: protos.google.cloud.compute.v1.IResizeInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IResizeInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    resize(request: protos.google.cloud.compute.v1.IResizeInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IResizeInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    resize(request: protos.google.cloud.compute.v1.IResizeInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IResizeInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setInstanceTemplate(request: protos.google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    setInstanceTemplate(request: protos.google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setInstanceTemplate(request: protos.google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetInstanceTemplateInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setTargetPools(request: protos.google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    setTargetPools(request: protos.google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setTargetPools(request: protos.google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetTargetPoolsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    updatePerInstanceConfigs(request: protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    updatePerInstanceConfigs(request: protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    updatePerInstanceConfigs(request: protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
