import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The Networks API.
 * @class
 * @memberof v1
 */
export declare class NetworksClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    networksStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of NetworksClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    addPeering(request: protos.google.cloud.compute.v1.IAddPeeringNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IAddPeeringNetworkRequest | undefined,
        {} | undefined
    ]>;
    addPeering(request: protos.google.cloud.compute.v1.IAddPeeringNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAddPeeringNetworkRequest | null | undefined, {} | null | undefined>): void;
    addPeering(request: protos.google.cloud.compute.v1.IAddPeeringNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAddPeeringNetworkRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeleteNetworkRequest | undefined,
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteNetworkRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteNetworkRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INetwork,
        protos.google.cloud.compute.v1.IGetNetworkRequest | undefined,
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INetwork, protos.google.cloud.compute.v1.IGetNetworkRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.INetwork, protos.google.cloud.compute.v1.IGetNetworkRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IInsertNetworkRequest | undefined,
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertNetworkRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertNetworkRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListNetworksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INetworkList,
        protos.google.cloud.compute.v1.IListNetworksRequest | undefined,
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListNetworksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INetworkList, protos.google.cloud.compute.v1.IListNetworksRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListNetworksRequest, callback: Callback<protos.google.cloud.compute.v1.INetworkList, protos.google.cloud.compute.v1.IListNetworksRequest | null | undefined, {} | null | undefined>): void;
    listPeeringRoutes(request: protos.google.cloud.compute.v1.IListPeeringRoutesNetworksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IExchangedPeeringRoutesList,
        (protos.google.cloud.compute.v1.IListPeeringRoutesNetworksRequest | undefined),
        {} | undefined
    ]>;
    listPeeringRoutes(request: protos.google.cloud.compute.v1.IListPeeringRoutesNetworksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IExchangedPeeringRoutesList, protos.google.cloud.compute.v1.IListPeeringRoutesNetworksRequest | null | undefined, {} | null | undefined>): void;
    listPeeringRoutes(request: protos.google.cloud.compute.v1.IListPeeringRoutesNetworksRequest, callback: Callback<protos.google.cloud.compute.v1.IExchangedPeeringRoutesList, protos.google.cloud.compute.v1.IListPeeringRoutesNetworksRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IPatchNetworkRequest | undefined,
        {} | undefined
    ]>;
    patch(request: protos.google.cloud.compute.v1.IPatchNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchNetworkRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchNetworkRequest | null | undefined, {} | null | undefined>): void;
    removePeering(request: protos.google.cloud.compute.v1.IRemovePeeringNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IRemovePeeringNetworkRequest | undefined,
        {} | undefined
    ]>;
    removePeering(request: protos.google.cloud.compute.v1.IRemovePeeringNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRemovePeeringNetworkRequest | null | undefined, {} | null | undefined>): void;
    removePeering(request: protos.google.cloud.compute.v1.IRemovePeeringNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRemovePeeringNetworkRequest | null | undefined, {} | null | undefined>): void;
    switchToCustomMode(request: protos.google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest | undefined),
        {} | undefined
    ]>;
    switchToCustomMode(request: protos.google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest | null | undefined, {} | null | undefined>): void;
    switchToCustomMode(request: protos.google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISwitchToCustomModeNetworkRequest | null | undefined, {} | null | undefined>): void;
    updatePeering(request: protos.google.cloud.compute.v1.IUpdatePeeringNetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IUpdatePeeringNetworkRequest | undefined,
        {} | undefined
    ]>;
    updatePeering(request: protos.google.cloud.compute.v1.IUpdatePeeringNetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IUpdatePeeringNetworkRequest | null | undefined, {} | null | undefined>): void;
    updatePeering(request: protos.google.cloud.compute.v1.IUpdatePeeringNetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IUpdatePeeringNetworkRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
