import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The NodeGroups API.
 * @class
 * @memberof v1
 */
export declare class NodeGroupsClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    nodeGroupsStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of NodeGroupsClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    addNodes(request: protos.google.cloud.compute.v1.IAddNodesNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IAddNodesNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    addNodes(request: protos.google.cloud.compute.v1.IAddNodesNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAddNodesNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    addNodes(request: protos.google.cloud.compute.v1.IAddNodesNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAddNodesNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListNodeGroupsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INodeGroupAggregatedList,
        (protos.google.cloud.compute.v1.IAggregatedListNodeGroupsRequest | undefined),
        {} | undefined
    ]>;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListNodeGroupsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INodeGroupAggregatedList, protos.google.cloud.compute.v1.IAggregatedListNodeGroupsRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListNodeGroupsRequest, callback: Callback<protos.google.cloud.compute.v1.INodeGroupAggregatedList, protos.google.cloud.compute.v1.IAggregatedListNodeGroupsRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeleteNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    deleteNodes(request: protos.google.cloud.compute.v1.IDeleteNodesNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeleteNodesNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    deleteNodes(request: protos.google.cloud.compute.v1.IDeleteNodesNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteNodesNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    deleteNodes(request: protos.google.cloud.compute.v1.IDeleteNodesNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteNodesNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INodeGroup,
        protos.google.cloud.compute.v1.IGetNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INodeGroup, protos.google.cloud.compute.v1.IGetNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.INodeGroup, protos.google.cloud.compute.v1.IGetNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicyNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IInsertNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListNodeGroupsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INodeGroupList,
        protos.google.cloud.compute.v1.IListNodeGroupsRequest | undefined,
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListNodeGroupsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INodeGroupList, protos.google.cloud.compute.v1.IListNodeGroupsRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListNodeGroupsRequest, callback: Callback<protos.google.cloud.compute.v1.INodeGroupList, protos.google.cloud.compute.v1.IListNodeGroupsRequest | null | undefined, {} | null | undefined>): void;
    listNodes(request: protos.google.cloud.compute.v1.IListNodesNodeGroupsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.INodeGroupsListNodes,
        protos.google.cloud.compute.v1.IListNodesNodeGroupsRequest | undefined,
        {} | undefined
    ]>;
    listNodes(request: protos.google.cloud.compute.v1.IListNodesNodeGroupsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.INodeGroupsListNodes, protos.google.cloud.compute.v1.IListNodesNodeGroupsRequest | null | undefined, {} | null | undefined>): void;
    listNodes(request: protos.google.cloud.compute.v1.IListNodesNodeGroupsRequest, callback: Callback<protos.google.cloud.compute.v1.INodeGroupsListNodes, protos.google.cloud.compute.v1.IListNodesNodeGroupsRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IPatchNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    patch(request: protos.google.cloud.compute.v1.IPatchNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest | undefined,
        {} | undefined
    ]>;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicyNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    setNodeTemplate(request: protos.google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest | undefined),
        {} | undefined
    ]>;
    setNodeTemplate(request: protos.google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    setNodeTemplate(request: protos.google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetNodeTemplateNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ITestPermissionsResponse,
        (protos.google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest | undefined),
        {} | undefined
    ]>;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsNodeGroupRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
