import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The Projects API.
 * @class
 * @memberof v1
 */
export declare class ProjectsClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    projectsStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of ProjectsClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    disableXpnHost(request: protos.google.cloud.compute.v1.IDisableXpnHostProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDisableXpnHostProjectRequest | undefined,
        {} | undefined
    ]>;
    disableXpnHost(request: protos.google.cloud.compute.v1.IDisableXpnHostProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDisableXpnHostProjectRequest | null | undefined, {} | null | undefined>): void;
    disableXpnHost(request: protos.google.cloud.compute.v1.IDisableXpnHostProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDisableXpnHostProjectRequest | null | undefined, {} | null | undefined>): void;
    disableXpnResource(request: protos.google.cloud.compute.v1.IDisableXpnResourceProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDisableXpnResourceProjectRequest | undefined),
        {} | undefined
    ]>;
    disableXpnResource(request: protos.google.cloud.compute.v1.IDisableXpnResourceProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDisableXpnResourceProjectRequest | null | undefined, {} | null | undefined>): void;
    disableXpnResource(request: protos.google.cloud.compute.v1.IDisableXpnResourceProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDisableXpnResourceProjectRequest | null | undefined, {} | null | undefined>): void;
    enableXpnHost(request: protos.google.cloud.compute.v1.IEnableXpnHostProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IEnableXpnHostProjectRequest | undefined,
        {} | undefined
    ]>;
    enableXpnHost(request: protos.google.cloud.compute.v1.IEnableXpnHostProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IEnableXpnHostProjectRequest | null | undefined, {} | null | undefined>): void;
    enableXpnHost(request: protos.google.cloud.compute.v1.IEnableXpnHostProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IEnableXpnHostProjectRequest | null | undefined, {} | null | undefined>): void;
    enableXpnResource(request: protos.google.cloud.compute.v1.IEnableXpnResourceProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IEnableXpnResourceProjectRequest | undefined),
        {} | undefined
    ]>;
    enableXpnResource(request: protos.google.cloud.compute.v1.IEnableXpnResourceProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IEnableXpnResourceProjectRequest | null | undefined, {} | null | undefined>): void;
    enableXpnResource(request: protos.google.cloud.compute.v1.IEnableXpnResourceProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IEnableXpnResourceProjectRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IProject,
        protos.google.cloud.compute.v1.IGetProjectRequest | undefined,
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IProject, protos.google.cloud.compute.v1.IGetProjectRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IProject, protos.google.cloud.compute.v1.IGetProjectRequest | null | undefined, {} | null | undefined>): void;
    getXpnHost(request: protos.google.cloud.compute.v1.IGetXpnHostProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IProject,
        protos.google.cloud.compute.v1.IGetXpnHostProjectRequest | undefined,
        {} | undefined
    ]>;
    getXpnHost(request: protos.google.cloud.compute.v1.IGetXpnHostProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IProject, protos.google.cloud.compute.v1.IGetXpnHostProjectRequest | null | undefined, {} | null | undefined>): void;
    getXpnHost(request: protos.google.cloud.compute.v1.IGetXpnHostProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IProject, protos.google.cloud.compute.v1.IGetXpnHostProjectRequest | null | undefined, {} | null | undefined>): void;
    getXpnResources(request: protos.google.cloud.compute.v1.IGetXpnResourcesProjectsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IProjectsGetXpnResources,
        (protos.google.cloud.compute.v1.IGetXpnResourcesProjectsRequest | undefined),
        {} | undefined
    ]>;
    getXpnResources(request: protos.google.cloud.compute.v1.IGetXpnResourcesProjectsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IProjectsGetXpnResources, protos.google.cloud.compute.v1.IGetXpnResourcesProjectsRequest | null | undefined, {} | null | undefined>): void;
    getXpnResources(request: protos.google.cloud.compute.v1.IGetXpnResourcesProjectsRequest, callback: Callback<protos.google.cloud.compute.v1.IProjectsGetXpnResources, protos.google.cloud.compute.v1.IGetXpnResourcesProjectsRequest | null | undefined, {} | null | undefined>): void;
    listXpnHosts(request: protos.google.cloud.compute.v1.IListXpnHostsProjectsRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IXpnHostList,
        protos.google.cloud.compute.v1.IListXpnHostsProjectsRequest | undefined,
        {} | undefined
    ]>;
    listXpnHosts(request: protos.google.cloud.compute.v1.IListXpnHostsProjectsRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IXpnHostList, protos.google.cloud.compute.v1.IListXpnHostsProjectsRequest | null | undefined, {} | null | undefined>): void;
    listXpnHosts(request: protos.google.cloud.compute.v1.IListXpnHostsProjectsRequest, callback: Callback<protos.google.cloud.compute.v1.IXpnHostList, protos.google.cloud.compute.v1.IListXpnHostsProjectsRequest | null | undefined, {} | null | undefined>): void;
    moveDisk(request: protos.google.cloud.compute.v1.IMoveDiskProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IMoveDiskProjectRequest | undefined,
        {} | undefined
    ]>;
    moveDisk(request: protos.google.cloud.compute.v1.IMoveDiskProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IMoveDiskProjectRequest | null | undefined, {} | null | undefined>): void;
    moveDisk(request: protos.google.cloud.compute.v1.IMoveDiskProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IMoveDiskProjectRequest | null | undefined, {} | null | undefined>): void;
    moveInstance(request: protos.google.cloud.compute.v1.IMoveInstanceProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IMoveInstanceProjectRequest | undefined,
        {} | undefined
    ]>;
    moveInstance(request: protos.google.cloud.compute.v1.IMoveInstanceProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IMoveInstanceProjectRequest | null | undefined, {} | null | undefined>): void;
    moveInstance(request: protos.google.cloud.compute.v1.IMoveInstanceProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IMoveInstanceProjectRequest | null | undefined, {} | null | undefined>): void;
    setCommonInstanceMetadata(request: protos.google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest | undefined),
        {} | undefined
    ]>;
    setCommonInstanceMetadata(request: protos.google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest | null | undefined, {} | null | undefined>): void;
    setCommonInstanceMetadata(request: protos.google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetCommonInstanceMetadataProjectRequest | null | undefined, {} | null | undefined>): void;
    setDefaultNetworkTier(request: protos.google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest | undefined),
        {} | undefined
    ]>;
    setDefaultNetworkTier(request: protos.google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest | null | undefined, {} | null | undefined>): void;
    setDefaultNetworkTier(request: protos.google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetDefaultNetworkTierProjectRequest | null | undefined, {} | null | undefined>): void;
    setUsageExportBucket(request: protos.google.cloud.compute.v1.ISetUsageExportBucketProjectRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetUsageExportBucketProjectRequest | undefined),
        {} | undefined
    ]>;
    setUsageExportBucket(request: protos.google.cloud.compute.v1.ISetUsageExportBucketProjectRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetUsageExportBucketProjectRequest | null | undefined, {} | null | undefined>): void;
    setUsageExportBucket(request: protos.google.cloud.compute.v1.ISetUsageExportBucketProjectRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetUsageExportBucketProjectRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
