import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The RegionInstanceGroupManagers API.
 * @class
 * @memberof v1
 */
export declare class RegionInstanceGroupManagersClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    regionInstanceGroupManagersStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of RegionInstanceGroupManagersClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    abandonInstances(request: protos.google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    abandonInstances(request: protos.google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    abandonInstances(request: protos.google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IAbandonInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    applyUpdatesToInstances(request: protos.google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    applyUpdatesToInstances(request: protos.google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    applyUpdatesToInstances(request: protos.google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IApplyUpdatesToInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    createInstances(request: protos.google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    createInstances(request: protos.google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    createInstances(request: protos.google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ICreateInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deleteInstances(request: protos.google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    deleteInstances(request: protos.google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deleteInstances(request: protos.google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deletePerInstanceConfigs(request: protos.google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    deletePerInstanceConfigs(request: protos.google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    deletePerInstanceConfigs(request: protos.google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeletePerInstanceConfigsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IInstanceGroupManager,
        (protos.google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManager, protos.google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IInstanceGroupManager, protos.google.cloud.compute.v1.IGetRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IRegionInstanceGroupManagerList,
        (protos.google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagerList, protos.google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagerList, protos.google.cloud.compute.v1.IListRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listErrors(request: protos.google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse,
        (protos.google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    listErrors(request: protos.google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse, protos.google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listErrors(request: protos.google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListErrorsResponse, protos.google.cloud.compute.v1.IListErrorsRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listManagedInstances(request: protos.google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse,
        (protos.google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    listManagedInstances(request: protos.google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse, protos.google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listManagedInstances(request: protos.google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListInstancesResponse, protos.google.cloud.compute.v1.IListManagedInstancesRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listPerInstanceConfigs(request: protos.google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp,
        (protos.google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest | undefined),
        {} | undefined
    ]>;
    listPerInstanceConfigs(request: protos.google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp, protos.google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    listPerInstanceConfigs(request: protos.google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest, callback: Callback<protos.google.cloud.compute.v1.IRegionInstanceGroupManagersListInstanceConfigsResp, protos.google.cloud.compute.v1.IListPerInstanceConfigsRegionInstanceGroupManagersRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    patch(request: protos.google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    patchPerInstanceConfigs(request: protos.google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    patchPerInstanceConfigs(request: protos.google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    patchPerInstanceConfigs(request: protos.google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchPerInstanceConfigsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    recreateInstances(request: protos.google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    recreateInstances(request: protos.google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    recreateInstances(request: protos.google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IRecreateInstancesRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    resize(request: protos.google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    resize(request: protos.google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    resize(request: protos.google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IResizeRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setInstanceTemplate(request: protos.google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    setInstanceTemplate(request: protos.google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setInstanceTemplate(request: protos.google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetInstanceTemplateRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setTargetPools(request: protos.google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    setTargetPools(request: protos.google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    setTargetPools(request: protos.google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetTargetPoolsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    updatePerInstanceConfigs(request: protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest | undefined),
        {} | undefined
    ]>;
    updatePerInstanceConfigs(request: protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    updatePerInstanceConfigs(request: protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IUpdatePerInstanceConfigsRegionInstanceGroupManagerRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
