import * as gax from 'google-gax';
import { Callback, CallOptions, Descriptors, ClientOptions } from 'google-gax';
import * as protos from '../../protos/protos';
/**
 *  The Subnetworks API.
 * @class
 * @memberof v1
 */
export declare class SubnetworksClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    subnetworksStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of SubnetworksClient.
     *
     * @param {object} [options] - The configuration object.
     * The options accepted by the constructor are described in detail
     * in [this document](https://github.com/googleapis/gax-nodejs/blob/master/client-libraries.md#creating-the-client-instance).
     * The common options are:
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     * @param {gax.ClientConfig} [options.clientConfig] - Client configuration override.
     *     Follows the structure of {@link gapicConfig}.
     * @param {boolean} [options.fallback] - Use HTTP fallback mode.
     *     In fallback mode, a special browser-compatible transport implementation is used
     *     instead of gRPC transport. In browser context (if the `window` object is defined)
     *     the fallback mode is enabled automatically; set `options.fallback` to `false`
     *     if you need to override this behavior.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     * @returns {string} The DNS address for this service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     * @returns {string} The DNS address for this service.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     * @returns {number} The default port for this service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     * @returns {string[]} List of default scopes.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListSubnetworksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ISubnetworkAggregatedList,
        (protos.google.cloud.compute.v1.IAggregatedListSubnetworksRequest | undefined),
        {} | undefined
    ]>;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListSubnetworksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ISubnetworkAggregatedList, protos.google.cloud.compute.v1.IAggregatedListSubnetworksRequest | null | undefined, {} | null | undefined>): void;
    aggregatedList(request: protos.google.cloud.compute.v1.IAggregatedListSubnetworksRequest, callback: Callback<protos.google.cloud.compute.v1.ISubnetworkAggregatedList, protos.google.cloud.compute.v1.IAggregatedListSubnetworksRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IDeleteSubnetworkRequest | undefined,
        {} | undefined
    ]>;
    delete(request: protos.google.cloud.compute.v1.IDeleteSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    delete(request: protos.google.cloud.compute.v1.IDeleteSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IDeleteSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    expandIpCidrRange(request: protos.google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest | undefined),
        {} | undefined
    ]>;
    expandIpCidrRange(request: protos.google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    expandIpCidrRange(request: protos.google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IExpandIpCidrRangeSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ISubnetwork,
        protos.google.cloud.compute.v1.IGetSubnetworkRequest | undefined,
        {} | undefined
    ]>;
    get(request: protos.google.cloud.compute.v1.IGetSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ISubnetwork, protos.google.cloud.compute.v1.IGetSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    get(request: protos.google.cloud.compute.v1.IGetSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.ISubnetwork, protos.google.cloud.compute.v1.IGetSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicySubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.IGetIamPolicySubnetworkRequest | undefined,
        {} | undefined
    ]>;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicySubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicySubnetworkRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.cloud.compute.v1.IGetIamPolicySubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.IGetIamPolicySubnetworkRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IInsertSubnetworkRequest | undefined,
        {} | undefined
    ]>;
    insert(request: protos.google.cloud.compute.v1.IInsertSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    insert(request: protos.google.cloud.compute.v1.IInsertSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IInsertSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListSubnetworksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ISubnetworkList,
        protos.google.cloud.compute.v1.IListSubnetworksRequest | undefined,
        {} | undefined
    ]>;
    list(request: protos.google.cloud.compute.v1.IListSubnetworksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ISubnetworkList, protos.google.cloud.compute.v1.IListSubnetworksRequest | null | undefined, {} | null | undefined>): void;
    list(request: protos.google.cloud.compute.v1.IListSubnetworksRequest, callback: Callback<protos.google.cloud.compute.v1.ISubnetworkList, protos.google.cloud.compute.v1.IListSubnetworksRequest | null | undefined, {} | null | undefined>): void;
    listUsable(request: protos.google.cloud.compute.v1.IListUsableSubnetworksRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IUsableSubnetworksAggregatedList,
        protos.google.cloud.compute.v1.IListUsableSubnetworksRequest | undefined,
        {} | undefined
    ]>;
    listUsable(request: protos.google.cloud.compute.v1.IListUsableSubnetworksRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IUsableSubnetworksAggregatedList, protos.google.cloud.compute.v1.IListUsableSubnetworksRequest | null | undefined, {} | null | undefined>): void;
    listUsable(request: protos.google.cloud.compute.v1.IListUsableSubnetworksRequest, callback: Callback<protos.google.cloud.compute.v1.IUsableSubnetworksAggregatedList, protos.google.cloud.compute.v1.IListUsableSubnetworksRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        protos.google.cloud.compute.v1.IPatchSubnetworkRequest | undefined,
        {} | undefined
    ]>;
    patch(request: protos.google.cloud.compute.v1.IPatchSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    patch(request: protos.google.cloud.compute.v1.IPatchSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.IPatchSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicySubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IPolicy,
        protos.google.cloud.compute.v1.ISetIamPolicySubnetworkRequest | undefined,
        {} | undefined
    ]>;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicySubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicySubnetworkRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.cloud.compute.v1.ISetIamPolicySubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IPolicy, protos.google.cloud.compute.v1.ISetIamPolicySubnetworkRequest | null | undefined, {} | null | undefined>): void;
    setPrivateIpGoogleAccess(request: protos.google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.IOperation,
        (protos.google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest | undefined),
        {} | undefined
    ]>;
    setPrivateIpGoogleAccess(request: protos.google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    setPrivateIpGoogleAccess(request: protos.google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.IOperation, protos.google.cloud.compute.v1.ISetPrivateIpGoogleAccessSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest, options?: CallOptions): Promise<[
        protos.google.cloud.compute.v1.ITestPermissionsResponse,
        (protos.google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest | undefined),
        {} | undefined
    ]>;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest, options: CallOptions, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest, callback: Callback<protos.google.cloud.compute.v1.ITestPermissionsResponse, protos.google.cloud.compute.v1.ITestIamPermissionsSubnetworkRequest | null | undefined, {} | null | undefined>): void;
    /**
     * Terminate the gRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     * @returns {Promise} A promise that resolves when the client is closed.
     */
    close(): Promise<void>;
}
